@@ -1,7 +1,7 @@
 <?php
 /*
 Plugin Name: CAS Authentication
-Version: 1.0
+Version: 1.4
 Plugin URI: http://non-gnu.uvt.nl/
 Description: Authenticate users using CAS. User info retrieved from LDAP.
 Author: Wessel Dankers
@@ -9,7 +9,7 @@ Author URI: mailto:wsl@uvt.nl
 */
 
 /*
- * $Id: cas-authentication.php 41119 2014-03-14 12:48:52Z wsl $
+ * $Id: cas-authentication.php 42712 2014-12-19 10:49:03Z wsl $
  * $URL: https://svn.uvt.nl/its-id/trunk/sources/wordpress-cas/cas-authentication.php $
  */
 
@@ -276,7 +276,7 @@ if(!class_exists('CASAuthenticationPlugin')) {
 		 */
 		function login($uid, $user) {
 			/* Clean the URL up (tickets are sort of sensitive data). */
-			if(cas_ticket())
+			if(cas_ticket() && !isset($_REQUEST['redirect_to']))
 				cas_redirect(cas_service());
 		}
 
